Python control of Innobus installation through Modbus serial Gateway
====================================================================

|PyPI version|

A simple Python API for controlling and interfacing with an Airzone installation devices using the modbus protocol.

This implementation is for the Innobus system.

.. |PyPI version| image:: https://badge.fury.io/py/python-airzone.svg
   :target: https://badge.fury.io/py/python-airzone







